@@ -10,7 +10,7 @@ package Pod::Simple::RTF;
 
 use strict;
 use vars qw($VERSION @ISA %Escape $WRAP %Tagmap);
-$VERSION = '1.01';
+$VERSION = '1.02';
 use Pod::Simple::PullParser ();
 BEGIN {@ISA = ('Pod::Simple::PullParser')}
 
@@ -37,7 +37,11 @@ my @_to_accept;
   'I=cs16\i',
   'C=cs19\f1\lang1024\noproof',
   'F=cs17\i\lang1024\noproof',
- 
+
+  'VerbatimI=cs26\i',
+  'VerbatimB=cs27\b',
+  'VerbatimBI=cs28\b\i',
+
   map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ }
    qw[
        underline=ul         smallcaps=scaps  shadow=shad
@@ -63,6 +67,8 @@ my @_to_accept;
 
  'Verbatim'  => "\n{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
  '/Verbatim' => "\n\\par}\n",
+ 'VerbatimFormatted'  => "\n{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
+ '/VerbatimFormatted' => "\n\\par}\n",
  'Para'    => "\n{\\pard\\li#rtfindent#\\sa180\n",
  '/Para'   => "\n\\par}\n",
  'head1'   => "\n{\\pard\\li#rtfindent#\\s31\\keepn\\sb90\\sa180\\f2\\fs#head1_halfpoint_size#\\ul{\n",
@@ -96,6 +102,7 @@ sub new {
   $new->{'Tagmap'} = {%Tagmap};
 
   $new->accept_codes(@_to_accept);
+  $new->accept_codes('VerbatimFormatted');
   DEBUG > 2 and print "To accept: ", join(' ',@_to_accept), "\n";
 
   $new->head1_halfpoint_size(32);
@@ -104,7 +111,7 @@ sub new {
   $new->head4_halfpoint_size(22);
   $new->codeblock_halfpoint_size(18);
   $new->header_halfpoint_size(17);
-  $new->normal_halfpoint_size(22);
+  $new->normal_halfpoint_size(25);
 
   return $new;
 }
@@ -186,7 +193,7 @@ sub do_middle {      # the main work
             [^\cm\cj\n\x20]{0,50}  #  and finish any current word
            )
            (\x20{1,10})(?![\cm\cj\n]) # capture some spaces not at line-end
-          /$1\n$2/gx     # and put a NL before those spaces
+          /$1$2\n/gx     # and put a NL before those spaces
         if $WRAP;
         # This may wrap at well past the 65th column, but not past the 120th.
       
@@ -196,7 +203,9 @@ sub do_middle {      # the main work
       DEBUG > 1 and print "  +$type ",$token->tagname,
         " (", map("<$_> ", %{$token->attr_hash}), ")\n";
 
-      if( ($tagname = $token->tagname) eq 'Verbatim' ) {
+      if( ($tagname = $token->tagname) eq 'Verbatim'
+          or $tagname eq 'VerbatimFormatted'
+      ) {
         ++$self->{'rtfverbatim'};
         my $next = $self->get_token;
         next unless defined $next;
@@ -223,6 +232,7 @@ sub do_middle {      # the main work
         while(1) {
           push @to_unget, $self->get_token;
           unshift(@to_unget), last unless defined $to_unget[-1];
+          
           if($to_unget[-1]->type eq 'text') {
             if( ($text_count_here += length ${$to_unget[-1]->text_r}) > 150 ){
               DEBUG > 1 and print "    item-* is too long to be keepn'd.\n";
@@ -293,7 +303,7 @@ sub do_middle {      # the main work
         DEBUG and print "Indenting back $indent_stack[-1] twips.\n";
         $self->{'rtfindent'} -= pop @indent_stack;
         pop @stack;
-      } elsif( $tagname eq 'Verbatim' ) {
+      } elsif( $tagname eq 'Verbatim' or $tagname eq 'VerbatimFormatted') {
         --$self->{'rtfverbatim'};
       }
       defined($scratch = $self->{'Tagmap'}{"/$tagname"}) or next;
@@ -342,6 +352,11 @@ sub stylesheet {
 {\*\cs23 \additive \i\lang1024\noproof\sbasedon10 pod-L-url;}
 {\*\cs24 \additive \i\lang1024\noproof\sbasedon10 pod-L-man;}
 
+{\*\cs25 \additive \f1\lang1024\noproof\sbasedon0 pod-codelbock-plain;}
+{\*\cs26 \additive \f1\lang1024\noproof\sbasedon25 pod-codelbock-ital;}
+{\*\cs27 \additive \f1\lang1024\noproof\sbasedon25 pod-codelbock-bold;}
+{\*\cs28 \additive \f1\lang1024\noproof\sbasedon25 pod-codelbock-bold-ital;}
+
 {\s31\ql \keepn\sb90\sa180\f2\fs%s\ul\sbasedon0 \snext0 pod-head1;}
 {\s32\ql \keepn\sb90\sa180\f2\fs%s\ul\sbasedon0 \snext0 pod-head2;}
 {\s33\ql \keepn\sb90\sa180\f2\fs%s\ul\sbasedon0 \snext0 pod-head3;}
@@ -362,13 +377,11 @@ END
 # Override these as necessary for further customization
 
 sub font_table {
-  # 
-
   return <<'END';  # text font, code font, heading font
 {\fonttbl
-{\f0\froman Georgia;}
+{\f0\froman Times New Roman;}
 {\f1\fmodern Courier New;}
-{\f2\fswiss Verdana;}
+{\f2\fswiss Arial;}
 }
 
 END
@@ -390,17 +403,31 @@ END
 
 sub doc_info {
    my $self = $_[0];
+
+   my $class = ref($self) || $self;
+
+   my $tag = __PACKAGE__ . ' ' . $VERSION;
+   
+   unless($class eq __PACKAGE__) {
+     $tag = " ($tag)";
+     $tag = " v" . $self->VERSION . $tag   if   defined $self->VERSION;
+     $tag = $class . $tag;
+   }
+
    return sprintf <<'END',
-{\info{\doccomm generated by %s v%s using %s v%s under
- Perl v%s at %s GMT}
+{\info{\doccomm
+%s
+ using %s v%s
+ under Perl v%s at %s GMT}
 {\author [see doc]}{\company [see doc]}{\operator [see doc]}
 }
 
 END
 
   # None of the following things should need escaping, I dare say!
-  ref($self), $self->VERSION(), $ISA[0], $ISA[0]->VERSION(),
-  $], scalar(gmtime),
+    $tag, 
+    $ISA[0], $ISA[0]->VERSION(),
+    $], scalar(gmtime),
   ;
 }
 
@@ -505,9 +532,9 @@ sub rtf_esc_codely {
   # will get munged.
 
   # And some refinements:
-  #"\n"   => "\n\\line ",
-  #"\cm"  => "\n\\line ",
-  #"\cj"  => "\n\\line ",
+  "\cm"  => "\n",
+  "\cj"  => "\n",
+  "\n"   => "\n\\line ",
 
   "\t"   => "\\tab ",     # Tabs (altho theoretically raw \t's are okay)
   "\f"   => "\n\\page\n", # Formfeed
